@@ -13,3 +13,11 @@ def catchtime(name: str):
     start = perf_counter()
     yield lambda: perf_counter() - start
     logger.info(f"\t\t complete in {perf_counter() - start:.3f} seconds")
+
+
+def human_readable_bytes(size: int) -> str:
+    for unit in ["B", "KB", "MB", "GB", "TB", "PB", "EB", "ZB"]:
+        if size < 1024:
+            return f"{size:.2f} {unit}"
+        size /= 1024
+    return f"{size:.2f} YB"
